#!/bin/sh

function myprint () {
  level=$1
  shift
  message="$*"
  if [ $verbose -ge $level ]
  then
    printf "$message"
  fi
}

function clean_exit () {
  if [ -e shrinking_photos.lock ]
  then
    rm shrinking_photos.lock 
  fi
  exit
}

function show_help () {
  printf "Usage: `basename $0` [-[no]1024] [-800] [-640] [-50p] [-h] [-q] <files_to_shrink>\n"
  printf "  This script shrinks the images supplied and \n"
  printf "  saves them as <image_name>_<res>.jpg\n"
  printf "  By default, it will only create pictures with\n"
  printf "  the horizontal dimension 1024 pixels.  Supply\n"
  printf "  the flag corresponding to the size you want to\n"
  printf "  create other sizes. \n"
  printf "Options:\n"
  printf "  -q      quiet.  Supresses output.\n"
  printf "  -h      help.  Shows this help message\n"
  printf "  -V      version.  Shows program version number\n"
  printf "  -1024   enables 1024 resolution output.\n"
  printf "  -no1024 disables 1024 resolution output.\n"
  printf "  -800, -640, -50p similar to 1024.  50p means 50%% reduction.\n"
  printf "Most Common Usage:\n"
  printf "  shrink_photos.sh \`find 2003.10.10 2003.10.11 -name \"dscn????.jpg\"\`\n\n"
  clean_exit
}


VERSION="0.1"

#### DEFAULTS ###
verbose=3
print_1024="yes"
print_800="no"
print_640="no"
print_50p="no"

while [ "x${1:0:1}" == "x-" ]
do
  case $1 in 
    ( -v )
       verbose=$(($verbose + 1))
	   ;;
    ( -vv )
       verbose=$(($verbose + 2))
	   ;;
    ( -vvv )
       verbose=$(($verbose + 3))
	   ;;
    ( -q )
       verbose=$(($verbose - 1))
	   ;;
    ( -qq )
       verbose=$(($verbose - 2))
	   ;;
    ( -qqq )
       verbose=$(($verbose - 3))
	   ;;
	( -h )
	   show_help
	   ;;
	( -V )
	   echo "Version: $VERSION"
	   exit 0
	   ;;
	( -1024 ) print_1024="yes" ;;
	( -no1024 ) print_1024="no" ;;
	( -800 ) print_800="yes" ;;
	( -no800 ) print_800="no" ;;
	( -640 ) print_640="yes" ;;
	( -no640 ) print_640="no" ;;
	( -50p ) print_50p="yes" ;;
	( -no50p ) print_50p="no" ;;
	(*)
	   echo "unrecognized option"
	   ;;
   esac
   shift
   if [ $verbose -lt 0 ]
   then
     verbose=0
   fi
done

touch shrinking_photos.lock
trap clean_exit 1 2 3 15
for i in `\ls -1 $@ | grep \.jpg | grep -v _tn.jpg | grep -v _640.jpg | grep -v _800.jpg | grep -v _1024.jpg | grep -v _50p.jpg`
  do
     printf "$i" >> shrinking_photos.lock
     myprint 3 "$i"
     j="${i/.jpg/}"
     if [ $print_1024 == "yes" ] && [ ! -e ${i/%.jpg/_1024.jpg} ]
     then
       convert -scale 1024 $i -resize 1024 ${i/%.jpg/_1024.jpg}
       printf " 1024" >> shrinking_photos.lock
       myprint 3 " 1024"
     else
       printf " skip" >> shrinking_photos.lock
       myprint 3 " skip"
     fi
     if [ $print_800 == "yes" ] && [ ! -e ${i/%.jpg/_800.jpg} ]
     then
       convert -scale 800 $i -resize 800 ${i/%.jpg/_800.jpg}
       printf " 800" >> shrinking_photos.lock
       myprint 3 " 800"
     else
       printf " skip" >> shrinking_photos.lock
       myprint 3 " skip"
     fi
    if [ $print_640 == "yes" ] && [ ! -e ${i/%.jpg/_640.jpg} ]
    then
      convert -scale 640 $i -resize 640 ${i/%.jpg/_640.jpg}
      printf " 640" >> shrinking_photos.lock
      myprint 3 " 640"
    else
      printf " skip" >> shrinking_photos.lock
      myprint 3 " skip"
    fi
    if [ $print_50p == "yes" ] && [ ! -e ${i/%.jpg/_50p.jpg} ]
    then
      convert -scale 50\% $i ${i/%.jpg/_50p.jpg}
      printf " 50%%" >>shrinking_photos.lock
      myprint 3 " 50%%"
    else
      printf " skip" >> shrinking_photos.lock
      myprint 3 " skip"
    fi
    printf "\n" >> shrinking_photos.lock
    myprint 3 "\n"
done
rm shrinking_photos.lock


